/*--------------------------------------------------------------------------+
$Id$
|                                                                          |
| Copyright 2014 ForTISS GmbH                     |
|                                                                          |
| Licensed under the Apache License, Version 2.0 (the "License");          |
| you may not use this file except in compliance with the License.         |
| You may obtain a copy of the License at                                  |
|                                                                          |
|    http://www.apache.org/licenses/LICENSE-2.0                            |
|                                                                          |
| Unless required by applicable law or agreed to in writing, software      |
| distributed under the License is distributed on an "AS IS" BASIS,        |
| WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. |
| See the License for the specific language governing permissions and      |
| limitations under the License.                                           |
+--------------------------------------------------------------------------*/
package org.fortiss.tooling.base.ui.annotation.labelprovider;

import static org.eclipse.wb.swt.SWTResourceManager.getColor;

import org.eclipse.jface.viewers.ColumnLabelProvider;
import org.eclipse.jface.viewers.TableViewer;
import org.eclipse.swt.graphics.Color;
import org.eclipse.swt.graphics.Point;
import org.fortiss.tooling.base.annotation.AnnotationEntry;
import org.fortiss.tooling.base.model.element.IModelElement;
import org.fortiss.tooling.base.ui.annotation.view.IAnnotationViewPart;
import org.fortiss.tooling.kernel.model.IIdLabeled;
import org.fortiss.tooling.kernel.model.INamedElement;

/**
 * Base class for {@link ColumnLabelProvider}s. The text labels are shown in {@link TableViewer}
 * -based annotation views when no item is selected for editing.
 * 
 * @author barner
 * @author $Author$
 * @version $Rev$
 * @ConQAT.Rating GREEN Hash: C6AC1E4683605D2F21CF0223816461FF
 */
public class LabelProviderBase extends ColumnLabelProvider {

	/** Color used to highlight currently selected row. */
	private static final Color HIGHLIGHT_SELECTED_ROW_COLOR = getColor(0, 255, 0);

	/** The view part in which this {@link LabelProviderBase} is used. */
	protected final IAnnotationViewPart viewPart;

	/** Creates a new {@link LabelProviderBase} for a given parent {@code viewPart}. */
	public LabelProviderBase(IAnnotationViewPart viewPart) {
		this.viewPart = viewPart;
	}

	/** {@inheritDoc} */
	@Override
	public Color getBackground(Object element) {
		if(element instanceof AnnotationEntry) {
			AnnotationEntry data = (AnnotationEntry)element;
			if(data.getModelElement().equals(viewPart.getCurrentlySelectedObject())) {
				return HIGHLIGHT_SELECTED_ROW_COLOR;
			}
		}
		return super.getBackground(element);
	}

	/** {@inheritDoc} */
	@Override
	public String getToolTipText(Object element) {
		if(!(element instanceof AnnotationEntry)) {
			return null;
		}

		IModelElement modelElement = ((AnnotationEntry)element).getModelElement();

		String rval = null;

		if(modelElement instanceof INamedElement) {
			rval = ((INamedElement)modelElement).getName();
		}

		if(modelElement instanceof IIdLabeled) {
			String id = "[Id=" + ((IIdLabeled)modelElement).getId() + "]";

			if(rval != null) {
				rval += " " + id;
			} else {
				rval = id;
			}
		}

		return rval;
	}

	/** {@inheritDoc} */
	@Override
	public Point getToolTipShift(Object object) {
		return new Point(15, 0);
	}

	/** {@inheritDoc} */
	@Override
	public int getToolTipDisplayDelayTime(Object object) {
		return 50; // msec
	}

	/** {@inheritDoc} */
	@Override
	public int getToolTipTimeDisplayed(Object object) {
		return 5000; // msec
	}
}
