/*--------------------------------------------------------------------------+
$Id: codetemplates.xml 1 2011-01-01 00:00:01Z hoelzl $
|                                                                          |
| Copyright 2013 ForTISS GmbH                     |
|                                                                          |
| Licensed under the Apache License, Version 2.0 (the "License");          |
| you may not use this file except in compliance with the License.         |
| You may obtain a copy of the License at                                  |
|                                                                          |
|    http://www.apache.org/licenses/LICENSE-2.0                            |
|                                                                          |
| Unless required by applicable law or agreed to in writing, software      |
| distributed under the License is distributed on an "AS IS" BASIS,        |
| WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. |
| See the License for the specific language governing permissions and      |
| limitations under the License.                                           |
+--------------------------------------------------------------------------*/
package org.fortiss.tooling.base.ui.compose;

import org.fortiss.tooling.base.model.base.EntryConnectorBase;
import org.fortiss.tooling.base.model.element.IConnector;
import org.fortiss.tooling.base.model.element.IHierarchicElement;
import org.fortiss.tooling.base.ui.dnd.gef.ConnectionDragContext;
import org.fortiss.tooling.base.ui.editpart.ElementEditPartBase;
import org.fortiss.tooling.base.ui.editpart.FreeConnectorEditPartBase;
import org.fortiss.tooling.kernel.extension.data.IConnectionCompositionContext;
import org.fortiss.tooling.kernel.extension.data.ITopLevelElement;
import org.fortiss.tooling.kernel.service.IPersistencyService;

/**
 * Compositor base class for connections between hierarchical elements and connectors.
 * 
 * @author igna
 * @author $Author: hoelzl $
 * @version $Rev: 18709 $
 * @ConQAT.Rating YELLOW Hash: B9DDD6EEA036E47CE1896B2FC5B1551A
 */
public abstract class HierarchicElementConnectorConnectionCompositorBase<HE extends IHierarchicElement, S extends IHierarchicElement, T extends IConnector>
		extends ConnectionCompositorBase<HE, S, T> {

	/** Creates the application specific source {@link IConnector} model element. */
	protected abstract IConnector createEntryConnector();

	/** Creates the application specific target {@link IConnector} model element. */
	protected abstract IConnector createExitConnector();

	/**
	 * Temporary storage of connection source (
	 * {@link #canConnect(IHierarchicElement, IConnector, IHierarchicElement, IConnectionCompositionContext)}
	 * must ensure that it is valid in {@link #canConnectInterally()}).
	 * 
	 * TODO (see #2234): Avoid this by refactoring the compositor interface to allow state based
	 * implementation.
	 */
	protected S source;

	/**
	 * Temporary storage of connection source (
	 * {@link #canConnect(IHierarchicElement, IConnector, IHierarchicElement, IConnectionCompositionContext)}
	 * must ensure that it is valid in {@link #canConnectInterally()}).
	 * 
	 * TODO (see #2234): Avoid this by refactoring the compositor interface to allow state based
	 * implementation.
	 */
	protected T target;

	/**
	 * Helper method to set temporary storage that allows state-based implementation of
	 * {@link #canConnectInterally()}.
	 * 
	 * TODO (see #2234): Avoid this by refactoring the compositor interface to allow state based
	 * implementation.
	 */
	protected void updateSourceTarget(S source, T target) {
		this.source = source;
		this.target = target;
	}

	/** {@inheritDoc} */
	@Override
	public boolean canConnect(S source, T target, HE parent, IConnectionCompositionContext context) {
		if(context instanceof ConnectionDragContext) {
			ConnectionDragContext dc = (ConnectionDragContext)context;
			if(dc.getTarget() instanceof FreeConnectorEditPartBase &&
					dc.getSource() instanceof ElementEditPartBase) {

				updateSourceTarget(source, target);
				boolean rval = canConnectInterally();
				updateSourceTarget(null, null);
				return rval;
			}
		}
		return true;
	}

	/** {@inheritDoc} */
	@Override
	protected boolean canConnectInterally() {
		return target.getIncoming().isEmpty();
	}

	/** {@inheritDoc} */
	@Override
	public boolean connect(S source, T target, HE parent, IConnectionCompositionContext context) {
		ITopLevelElement topElement = IPersistencyService.INSTANCE.getTopLevelElementFor(parent);

		IConnector sourceConnector = null;
		if(sameParent(source, target)) {
			if(target instanceof EntryConnectorBase) {
				sourceConnector = createEntryConnector();
			} else {
				sourceConnector = createExitConnector();
			}
		} else {
			if(target instanceof EntryConnectorBase) {
				sourceConnector = createExitConnector();
			} else {
				sourceConnector = createEntryConnector();
			}
		}

		avoidDuplicateConnectorName(source, sourceConnector);

		if(topElement != null) {
			topElement.prepareIDs(sourceConnector);
		}
		createNewSourceDropContext(source, context, sourceConnector);

		createConnection(sourceConnector, target, parent, topElement);
		return true;
	}
}
