/*--------------------------------------------------------------------------+
$Id$
|                                                                          |
| Copyright 2011 ForTISS GmbH                     |
|                                                                          |
| Licensed under the Apache License, Version 2.0 (the "License");          |
| you may not use this file except in compliance with the License.         |
| You may obtain a copy of the License at                                  |
|                                                                          |
|    http://www.apache.org/licenses/LICENSE-2.0                            |
|                                                                          |
| Unless required by applicable law or agreed to in writing, software      |
| distributed under the License is distributed on an "AS IS" BASIS,        |
| WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. |
| See the License for the specific language governing permissions and      |
| limitations under the License.                                           |
+--------------------------------------------------------------------------*/
package org.fortiss.tooling.kernel.internal;

import org.eclipse.core.runtime.Assert;
import org.eclipse.core.runtime.IProgressMonitor;
import org.eclipse.emf.common.command.CommandStackListener;
import org.eclipse.emf.common.util.TreeIterator;
import org.eclipse.emf.ecore.EObject;
import org.eclipse.emf.ecore.resource.ResourceSet;
import org.fortiss.tooling.kernel.extension.data.ITopLevelElement;
import org.fortiss.tooling.kernel.model.IIdLabeled;
import org.fortiss.tooling.kernel.service.IPersistencyService;

/**
 * The dummy top-level element is used to load models into the {@link IPersistencyService} without
 * an actual underlying storage. This is
 * primarily intended to load models for unit testing.
 * 
 * @author hoelzl
 * @author $Author$
 * @version $Rev$
 * @ConQAT.Rating YELLOW Hash: 1085F8EFF356A0082ADCA16F6373B3E3
 */
final class DummyTopLevelElement implements ITopLevelElement {

	/** Stores the root element. */
	private final EObject root;

	/** Constructor. */
	public DummyTopLevelElement(EObject root) {
		Assert.isNotNull(root);
		this.root = root;
	}

	/** {@inheritDoc} */
	@Override
	public EObject getRootModelElement() {
		return root;
	}

	/** {@inheritDoc} */
	@Override
	public void runAsCommand(Runnable runner) {
		runner.run();
	}

	/** {@inheritDoc} */
	@Override
	public void runAsNonDirtyingCommand(Runnable runner) {
		runner.run();
	}

	/** {@inheritDoc} */
	@Override
	public void addCommandStackListener(CommandStackListener listener) {
		// ignore
	}

	/** {@inheritDoc} */
	@Override
	public void removeCommandStackListener(CommandStackListener listener) {
		// ignore
	}

	/** {@inheritDoc} */
	@Override
	public boolean canUndo() {
		return false;
	}

	/** {@inheritDoc} */
	@Override
	public boolean canRedo() {
		return false;
	}

	/** {@inheritDoc} */
	@Override
	public void undo() {
		// ignore
	}

	/** {@inheritDoc} */
	@Override
	public void redo() {
		// ignore
	}

	/** {@inheritDoc} */
	@Override
	public boolean isDirty() {
		return false;
	}

	/** {@inheritDoc} */
	@Override
	public String getSaveableName() {
		return "Dummy";
	}

	/** {@inheritDoc} */
	@Override
	public void doSave(IProgressMonitor monitor) {
		// ignore
	}

	/** {@inheritDoc} */
	@Override
	public void doSaveAndResetLastChangeWasIntended(IProgressMonitor monitor) {
		// ignore

	}

	/** {@inheritDoc} */
	@Override
	public void prepareIDs(EObject modelElement) {
		if(!(modelElement instanceof IIdLabeled))
			return;

		int id = Integer.MIN_VALUE;
		for(TreeIterator<EObject> iter = getRootModelElement().eAllContents(); iter.hasNext();) {
			EObject o = iter.next();
			if(o instanceof IIdLabeled) {
				id = Math.max(id, ((IIdLabeled)o).getId());
			}
		}

		((IIdLabeled)modelElement).setId(id + 1);
	}

	/** {@inheritDoc} */
	@Override
	public boolean canDelete() {
		return false;
	}

	/** {@inheritDoc} */
	@Override
	public boolean delete() {
		return false;
	}

	/** {@inheritDoc} */
	@Override
	public ResourceSet getResourceSet() {
		return null;
	}
}
