/*-------------------------------------------------------------------------+
|                                                                          |
| Copyright 2005-2011 The ConQAT Project                                   |
|                                                                          |
| Licensed under the Apache License, Version 2.0 (the "License");          |
| you may not use this file except in compliance with the License.         |
| You may obtain a copy of the License at                                  |
|                                                                          |
|    http://www.apache.org/licenses/LICENSE-2.0                            |
|                                                                          |
| Unless required by applicable law or agreed to in writing, software      |
| distributed under the License is distributed on an "AS IS" BASIS,        |
| WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. |
| See the License for the specific language governing permissions and      |
| limitations under the License.                                           |
+-------------------------------------------------------------------------*/
package org.conqat.ide.commons.ui;

import org.eclipse.jface.resource.ImageDescriptor;
import org.eclipse.jface.resource.ImageRegistry;
import org.eclipse.swt.graphics.Image;

/**
 * Enumeration that provides all images used in the application. This
 * enumeration uses the image registry provided by Eclipse.
 * 
 * @author deissenb
 * @author $Author: deissenb $
 * @version $Rev: 34252 $
 * @levd.rating GREEN Hash: C81DAC4C4236F05E61514A20E1DEA4AA
 */
public enum ECCSMCommonsImage {

	/** Icon used for thumbnail view in outline. */
	THUMBNAIL_VIEW,

	/** Icon used for Tree view */
	TREE_VIEW,

	/** Error icon */
	ERROR,

	/** Warning icon */
	WARNING,

	/** Wizard banner for error page. */
	ERROR_WIZBAN,

	/** Icon for open projects */
	OPEN_PROJECT,

	/** For clearing filters and similar actions. */
	CLEAR,

	/** Same as clear but disabled. */
	CLEAR_DISABLED,

	/** Expand all icon. */
	EXPAND_ALL,

	/** Collapse all icon. */
	COLLAPSE_ALL,

	/** Info icon. */
	INFO,

	/** Refresh icon. */
	REFRESH;

	/**
	 * Register all images defined in this enumeration with the given image
	 * registry. This needs to be called only once.
	 */
	public static void registerImages(ImageRegistry registry) {
		for (ECCSMCommonsImage image : values()) {
			registry.put(image.getImageName(), image.getImageDescriptor());
		}
	}

	/** Get image registry from {@link CCSMCommonsActivator}. */
	private static ImageRegistry getRegistry() {
		return CCSMCommonsActivator.getDefault().getImageRegistry();
	}

	/** Get image for enumeration element. */
	public Image getImage() {
		return getRegistry().get(getImageName());
	}

	/** Get image descriptor for enumeration element. */
	public ImageDescriptor getImageDescriptor() {
		return CCSMCommonsActivator.getImageDescriptor(getImagePath());
	}

	/** Get image name. */
	private String getImageName() {
		return name().toLowerCase();
	}

	/** Get path to image. */
	private String getImagePath() {
		return "icons/" + getImageName() + ".png";
	}
}