/*-------------------------------------------------------------------------+
|                                                                          |
| Copyright 2005-2011 The ConQAT Project                                   |
|                                                                          |
| Licensed under the Apache License, Version 2.0 (the "License");          |
| you may not use this file except in compliance with the License.         |
| You may obtain a copy of the License at                                  |
|                                                                          |
|    http://www.apache.org/licenses/LICENSE-2.0                            |
|                                                                          |
| Unless required by applicable law or agreed to in writing, software      |
| distributed under the License is distributed on an "AS IS" BASIS,        |
| WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. |
| See the License for the specific language governing permissions and      |
| limitations under the License.                                           |
+-------------------------------------------------------------------------*/
package org.conqat.ide.commons.ui.core;

import java.io.IOException;
import java.net.URL;

import org.conqat.lib.commons.filesystem.ClassPathUtils;
import org.conqat.lib.commons.filesystem.ClassPathUtils.IURLResolver;
import org.eclipse.core.runtime.FileLocator;

/**
 * Utility class for dealing with class paths that is aware of Eclipse URL
 * locations.
 * 
 * @author $Author: deissenb $
 * @version $Rev: 34252 $
 * @levd.rating GREEN Hash: CC777DA50E7DBCB9606625B2D0381533
 */
public class EclipseClassPathUtils {

	/** Resolver that can deal with bundleresource URLs. */
	public static final IURLResolver FILELOCATOR_RESOLVER = new IURLResolver() {

		@Override
		public URL resolve(URL url) throws IOException {
			// the Eclipse class loaders return 'bundleresource' URLs that need
			// to
			// be resolved
			if ("bundleresource".equals(url.getProtocol())) {
				url = FileLocator.resolve(url);
			}
			return url;
		}
	};

	/** Creates a classpath from the anchor classes as a single string. */
	public static String createClassPathAsString(Class<?>... anchorClasses)
			throws IOException {
		return ClassPathUtils.createClassPathAsString(FILELOCATOR_RESOLVER,
				anchorClasses);
	}

	/** Creates a classpath from the anchor classes as an array. */
	public static String[] createClassPathAsArray(Class<?>... anchorClasses)
			throws IOException {
		return ClassPathUtils.createClassPathAsArray(FILELOCATOR_RESOLVER,
				anchorClasses);
	}
}