/*-------------------------------------------------------------------------+
|                                                                          |
| Copyright 2005-2011 The ConQAT Project                                   |
|                                                                          |
| Licensed under the Apache License, Version 2.0 (the "License");          |
| you may not use this file except in compliance with the License.         |
| You may obtain a copy of the License at                                  |
|                                                                          |
|    http://www.apache.org/licenses/LICENSE-2.0                            |
|                                                                          |
| Unless required by applicable law or agreed to in writing, software      |
| distributed under the License is distributed on an "AS IS" BASIS,        |
| WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. |
| See the License for the specific language governing permissions and      |
| limitations under the License.                                           |
+-------------------------------------------------------------------------*/
package org.conqat.ide.commons.ui.extension;

import java.util.ArrayList;
import java.util.Collections;
import java.util.List;

import org.eclipse.core.runtime.IConfigurationElement;
import org.eclipse.core.runtime.IExtension;
import org.eclipse.core.runtime.IExtensionPoint;
import org.eclipse.core.runtime.IStatus;
import org.eclipse.core.runtime.Platform;
import org.eclipse.jface.resource.ImageDescriptor;
import org.osgi.framework.Bundle;

import org.conqat.ide.commons.ui.CCSMCommonsActivator;
import org.conqat.ide.commons.ui.logging.LoggingUtils;

/**
 * Utility methods for the extension points of plug-ins.
 * 
 * @author hummelb
 * @author $Author: deissenb $
 * @version $Rev: 34252 $
 * @levd.rating GREEN Hash: 3A6C32DF7541A73EFF1BBA7204FFB23D
 */
public class ExtensionPointUtils {

	/** Load the given class and throws an exception in case of problems. */
	public static Class<?> loadClass(String className, Bundle bundle)
			throws ClassNotFoundException {
		if (className == null) {
			throw new ClassNotFoundException("Class name not configured.");
		}
		return bundle.loadClass(className);
	}

	/** Load the icon descriptor or return null if null is provided. */
	public static ImageDescriptor loadIconDescriptor(String iconLocation,
			Bundle bundle) {
		if (iconLocation == null) {
			return null;
		}
		return ImageDescriptor.createFromURL(bundle.getResource(iconLocation));
	}

	/** Returns the bundle an extension is declared in. */
	public static Bundle getBundle(IConfigurationElement configElement) {
		Bundle bundle = Platform.getBundle(configElement
				.getDeclaringExtension().getNamespaceIdentifier());
		return bundle;
	}

	/**
	 * Returns the {@link IConfigurationElement}s for a given extension point
	 * and element name.
	 */
	@SuppressWarnings("unchecked")
	public static List<IConfigurationElement> getConfigurationElements(
			String extensionPointName, String configurationElementName) {
		IExtensionPoint extensionPoint = Platform.getExtensionRegistry()
				.getExtensionPoint(extensionPointName);
		if (extensionPoint == null) {
			LoggingUtils.log(CCSMCommonsActivator.getDefault(),
					"Could not find extension point " + extensionPointName,
					IStatus.ERROR);
			return Collections.EMPTY_LIST;
		}

		List<IConfigurationElement> configurationElements = new ArrayList<IConfigurationElement>();
		for (IExtension e : extensionPoint.getExtensions()) {
			for (IConfigurationElement ce : e.getConfigurationElements()) {
				if (ce.getName().equals(configurationElementName)) {
					configurationElements.add(ce);
				}
			}
		}
		return configurationElements;
	}
}