/*-------------------------------------------------------------------------+
|                                                                          |
| Copyright 2005-2011 The ConQAT Project                                   |
|                                                                          |
| Licensed under the Apache License, Version 2.0 (the "License");          |
| you may not use this file except in compliance with the License.         |
| You may obtain a copy of the License at                                  |
|                                                                          |
|    http://www.apache.org/licenses/LICENSE-2.0                            |
|                                                                          |
| Unless required by applicable law or agreed to in writing, software      |
| distributed under the License is distributed on an "AS IS" BASIS,        |
| WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. |
| See the License for the specific language governing permissions and      |
| limitations under the License.                                           |
+-------------------------------------------------------------------------*/
package org.conqat.ide.commons.ui.marker;

import java.util.HashMap;

import org.eclipse.core.resources.IMarker;

import org.conqat.ide.commons.ui.ECCSMCommonsImage;

/**
 * Severity enum wrapping the Eclipse {@link IMarker} severity concept.
 * 
 * @author heineman
 * @author $Author$
 * @version $Rev$
 * @levd.rating GREEN Hash: D0D06BB23439A4EFBC0BA8F39EB0D7F3
 */
public enum EMarkerSeverity {

	/** warning severity */
	WARNING(IMarker.SEVERITY_WARNING, ECCSMCommonsImage.WARNING),
	/** error severity */
	ERROR(IMarker.SEVERITY_ERROR, ECCSMCommonsImage.ERROR),
	/** info severity */
	INFO(IMarker.SEVERITY_INFO, ECCSMCommonsImage.INFO);

	/** The icon associated with this severity. */
	private final ECCSMCommonsImage icon;

	/** This maps from eclipse severity to enum element. */
	private static final HashMap<Integer, EMarkerSeverity> map = new HashMap<Integer, EMarkerSeverity>();

	// init map
	static {
		for (EMarkerSeverity severity : values()) {
			map.put(severity.eclipseSeverity, severity);
		}
	}

	/**
	 * The severity as in {@link IMarker}.
	 */
	private final int eclipseSeverity;

	/**
	 * Constructs a new {@link EMarkerSeverity}.
	 * 
	 * @param eclipseSeverity
	 *            the severity as in {@link IMarker}.
	 */
	private EMarkerSeverity(int eclipseSeverity, ECCSMCommonsImage icon) {
		this.eclipseSeverity = eclipseSeverity;
		this.icon = icon;
	}

	/**
	 * Returns the severity as defined in {@link IMarker}.
	 */
	public int getEclipseSeverity() {
		return eclipseSeverity;
	}

	/**
	 * Returns the enum element that matches the Eclipse severity. This may
	 * return <code>null</code> .
	 */
	public static EMarkerSeverity getSeverity(int eclipseSeverity) {
		return map.get(eclipseSeverity);
	}

	/** Get the icon associated with this severity. */
	public ECCSMCommonsImage getIcon() {
		return icon;
	}

}